@@ -1,6 +1,6 @@
 # Copyright (C) 2003-2008 by Dr. Dieter Maurer <dieter@handshake.de>
 # see "LICENSE.txt" for details
-#       $Id: ZopeProfiler.py,v 1.1.1.1 2008/08/18 10:17:30 dieter Exp $
+#       $Id: ZopeProfiler.py,v 1.2 2011-11-13 09:52:57 dieter Exp $
 '''ZopeProfiler.
 
   'ZopeProfiler' supports both low level and high level profiling for Zope
@@ -231,13 +231,17 @@ class ZopeProfiler(SimpleItem,PropertyManager):
       if not res: res = 'No matching functions'
       return res
     else:
-      stdout=sys.stdout
-      sys.stdout=output # ATT: this is dangerous
+      if hasattr(stats, "stream"):
+        # Python 2.6 and above
+        stats.stream = output
+      else:
+        stdout=sys.stdout
+        sys.stdout=output # ATT: this is dangerous
       try:
         getattr(stats,'print_%s' % mode)(*filter)
         return output.getvalue()
       finally:
-        sys.stdout=stdout
+        if not hasattr(stats, "stream"): sys.stdout=stdout
 
   def _getStatistics(self,what):
     '''return the statistics object.'''
@@ -460,6 +464,9 @@ class ZProfiler(HLProfiler):
 
 
 # $Log: ZopeProfiler.py,v $
+# Revision 1.2  2011-11-13 09:52:57  dieter
+# 2.0.2: compatibilty with Zope 2.12/2.13
+#
 # Revision 1.1.1.1  2008/08/18 10:17:30  dieter
 # ZopeProfiler 2.0
 #
